From b4f8838b15342670c31753a484abf0129e3c9653 Mon Sep 17 00:00:00 2001
From: jcduff <jcduff@localhost>
Date: Thu, 23 Oct 2008 14:04:24 +0000
Subject: [PATCH] The commit will bring the following features : - An updated version of the underlying database. BDB JE 3.3 is now used. - Attribute API refactoring providing a better abstraction and offering improved performances. - A new GUI called the Control-Panel to replace the Status-Panel: the specifications for this GUI are available on OpenDS Wiki and contains a link to a mockup. See <https://www.opends.org/wiki/page/ControlPanelUISpecification>. - Some changes in the replication protocol to implement "Assured Replication Mode". The specifications are on OpenDS Wiki at <https://www.opends.org/wiki/page/AssuredMode> and section 7 described some of the replication changes required to support this. Assured Replication is not finished, but the main replication protocol changes to support it are done. As explained by Gilles on an email on the Dev mailing list (http://markmail.org/message/46rgo3meq3vriy4a), with these changes the newer versions of OpenDS may not be able to replicate with OpenDS 1.0 instances. - Support for Service Tags on the platforms where the functionality is available and enabled. Specifications are published at <https://www.opends.org/wiki/page/OpenDSServiceTagEnabled>. For more information on Service Tags see <http://wikis.sun.com/display/ServiceTag/Sun+Service+Tag+FAQ>. - The Admin Connector service. In order to provide agentry of the OpenDS server at any time, a new service has been added, dedicated to the administration, configuration and monitoring of the server. An overview of the Admin Connector service and it's use is available on the OpenDS wiki <https://www.opends.org/wiki/page/ManagingAdministrationTrafficToTheServer> - Updates to the various command line tools to support the Admin Connector service. - Some internal re-architecting of the server to put the foundation of future developments such as virtual directory services. The new NetworkGroups and WorkFlow internal services which have been specified in <https://www.opends.org/wiki/page/BasicOperationRoutingThroughNetworkGroup> are now implemented. - Many bug fixes...
---
opendj-sdk/opends/src/server/org/opends/server/replication/server/MsgQueue.java | 54 +++++++++++++++++++++++++++---------------------------
1 files changed, 27 insertions(+), 27 deletions(-)
diff --git a/opendj-sdk/opends/src/server/org/opends/server/replication/server/MsgQueue.java b/opendj-sdk/opends/src/server/org/opends/server/replication/server/MsgQueue.java
index 3484633..c74ccbe 100644
--- a/opendj-sdk/opends/src/server/org/opends/server/replication/server/MsgQueue.java
+++ b/opendj-sdk/opends/src/server/org/opends/server/replication/server/MsgQueue.java
@@ -30,37 +30,37 @@
import java.util.TreeMap;
import org.opends.server.replication.common.ChangeNumber;
-import org.opends.server.replication.protocol.UpdateMessage;
+import org.opends.server.replication.protocol.UpdateMsg;
/**
* This class is used to build ordered lists of UpdateMessage.
* The order is defined by the order of the ChangeNumber of the UpdateMessage.
*/
public class MsgQueue
{
- private SortedMap<ChangeNumber, UpdateMessage> map =
- new TreeMap<ChangeNumber, UpdateMessage>();
+ private SortedMap<ChangeNumber, UpdateMsg> map =
+ new TreeMap<ChangeNumber, UpdateMsg>();
// The total number of bytes for all the message in the queue.
private int bytesCount = 0;
/**
* Return the first UpdateMessage in the MsgQueue.
*
* @return The first UpdateMessage in the MsgQueue.
*/
- public UpdateMessage first()
+ public UpdateMsg first()
{
return map.get(map.firstKey());
}
/**
* Return the last UpdateMessage in the MsgQueue.
*
* @return The last UpdateMessage in the MsgQueue.
*/
- public UpdateMessage last()
+ public UpdateMsg last()
{
return map.get(map.lastKey());
}
@@ -86,9 +86,9 @@
}
/**
* Returns <tt>true</tt> if this MsgQueue contains no UpdateMessage.
*
* @return <tt>true</tt> if this MsgQueue contains no UpdateMessage.
*/
public boolean isEmpty()
{
@@ -97,46 +97,46 @@
/**
* Add an UpdateMessage to this MessageQueue.
*
* @param update The UpdateMessage to add to this MessageQueue.
*/
- public void add(UpdateMessage update)
+ public void add(UpdateMsg update)
{
map.put(update.getChangeNumber(), update);
bytesCount += update.size();
}
/**
* Get and remove the first UpdateMessage in this MessageQueue.
*
* @return The first UpdateMessage in this MessageQueue.
*/
- public UpdateMessage removeFirst()
+ public UpdateMsg removeFirst()
{
- UpdateMessage msg = map.get(map.firstKey());
+ UpdateMsg msg = map.get(map.firstKey());
map.remove(msg.getChangeNumber());
bytesCount -= msg.size();
return msg;
}
/**
* Returns <tt>true</tt> if this map contains an UpdateMessage
* with the same ChangeNumber as the given UpdateMessage.
*
* @param msg UpdateMessage whose presence in this queue is to be tested.
*
* @return <tt>true</tt> if this map contains an UpdateMessage
* with the same ChangeNumber as the given UpdateMessage.
*
*/
- public boolean contains(UpdateMessage msg)
+ public boolean contains(UpdateMsg msg)
{
return map.containsKey(msg.getChangeNumber());
}
/**
* Removes all UpdateMessage form this queue.
*/
public void clear()
{
@@ -30,37 +30,37 @@
/**
- * This class is used to build ordered lists of UpdateMessage.
- * The order is defined by the order of the ChangeNumber of the UpdateMessage.
+ * This class is used to build ordered lists of UpdateMsg.
+ * The order is defined by the order of the ChangeNumber of the UpdateMsg.
*/
public class MsgQueue
@@ -30,37 +30,37 @@
private int bytesCount = 0;
/**
- * Return the first UpdateMessage in the MsgQueue.
+ * Return the first UpdateMsg in the MsgQueue.
*
@@ -30,37 +30,37 @@
*
- * @return The first UpdateMessage in the MsgQueue.
+ * @return The first UpdateMsg in the MsgQueue.
*/
@@ -30,37 +30,37 @@
}
/**
- * Return the last UpdateMessage in the MsgQueue.
+ * Return the last UpdateMsg in the MsgQueue.
*
@@ -30,37 +30,37 @@
*
- * @return The last UpdateMessage in the MsgQueue.
+ * @return The last UpdateMsg in the MsgQueue.
*/
@@ -86,9 +86,9 @@
}
/**
- * Returns <tt>true</tt> if this MsgQueue contains no UpdateMessage.
+ * Returns <tt>true</tt> if this MsgQueue contains no UpdateMsg.
*
@@ -86,9 +86,9 @@
*
- * @return <tt>true</tt> if this MsgQueue contains no UpdateMessage.
+ * @return <tt>true</tt> if this MsgQueue contains no UpdateMsg.
*/
public boolean isEmpty()
@@ -97,46 +97,46 @@
/**
- * Add an UpdateMessage to this MessageQueue.
+ * Add an UpdateMsg to this MessageQueue.
*
@@ -97,46 +97,46 @@
*
- * @param update The UpdateMessage to add to this MessageQueue.
+ * @param update The UpdateMsg to add to this MessageQueue.
*/
@@ -97,46 +97,46 @@
}
/**
- * Get and remove the first UpdateMessage in this MessageQueue.
+ * Get and remove the first UpdateMsg in this MessageQueue.
*
@@ -97,46 +97,46 @@
*
- * @return The first UpdateMessage in this MessageQueue.
+ * @return The first UpdateMsg in this MessageQueue.
*/
@@ -97,46 +97,46 @@
}
/**
- * Returns <tt>true</tt> if this map contains an UpdateMessage
- * with the same ChangeNumber as the given UpdateMessage.
+ * Returns <tt>true</tt> if this map contains an UpdateMsg
+ * with the same ChangeNumber as the given UpdateMsg.
*
@@ -97,46 +97,46 @@
*
- * @param msg UpdateMessage whose presence in this queue is to be tested.
+ * @param msg UpdateMsg whose presence in this queue is to be tested.
*
@@ -97,46 +97,46 @@
*
- * @return <tt>true</tt> if this map contains an UpdateMessage
- * with the same ChangeNumber as the given UpdateMessage.
+ * @return <tt>true</tt> if this map contains an UpdateMsg
+ * with the same ChangeNumber as the given UpdateMsg.
*
*/
@@ -97,46 +97,46 @@
}
/**
- * Removes all UpdateMessage form this queue.
+ * Removes all UpdateMsg form this queue.
*/
public void clear()
--
Gitblit v1.10.0